from setuptools import setup, find_packages


GITHUB_REPO = 'chickenzord/dotenvy'
VERSION = '0.1.1'
ARCHIVE_URL = 'https://github.com/%s/archive/%s.tar.gz' % (GITHUB_REPO, VERSION)

setup(
    name='dotenvy',
    version=VERSION,
    packages=find_packages('src'),
    package_dir={'': 'src'},
    package_data={},
    install_requires=[
        'future',
    ],
    zip_safe=False,

    # metadata
    author='Akhyar Amarullah',
    author_email='akhyrul@gmail.com',
    description='Dotenv handler for Python',
    long_description=open('README.rst').read(),
    download_url=ARCHIVE_URL,
    license='MIT',
    keywords=['dotenv', 'configuration', 'environment'],
    url='https://github.com/%s' % (GITHUB_REPO),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Utilities',
    ],
)



from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
from builtins import open
from future import standard_library
standard_library.install_aliases()

from os import environ
from .parser import parse_string
from .parser import truthy  # noqa


def load_env(envs):
    for k in envs:
        environ[k] = envs[k]


def load_string(string):
    load_env(parse_string(string))


def read(file, schema={}, *args, **kwargs):
    return parse_string(file.read(), *args, **kwargs)


def read_file(filepath, schema={}, *args, **kwargs):
    return read(open(filepath), *args, **kwargs)
